@@ -71,7 +71,6 @@ pub trait ModuleLoader {
   /// apply import map for child imports.
   fn resolve(
     &self,
-    op_state: Rc<RefCell<OpState>>,
     specifier: &str,
     referrer: &str,
     _is_main: bool,
@@ -83,7 +82,6 @@ pub trait ModuleLoader {
   /// dynamic imports altogether.
   fn load(
     &self,
-    op_state: Rc<RefCell<OpState>>,
     module_specifier: &ModuleSpecifier,
     maybe_referrer: Option<ModuleSpecifier>,
     is_dyn_import: bool,
@@ -116,7 +114,6 @@ pub struct NoopModuleLoader;
 impl ModuleLoader for NoopModuleLoader {
   fn resolve(
     &self,
-    _op_state: Rc<RefCell<OpState>>,
     _specifier: &str,
     _referrer: &str,
     _is_main: bool,
@@ -126,7 +123,6 @@ impl ModuleLoader for NoopModuleLoader {
 
   fn load(
     &self,
-    _op_state: Rc<RefCell<OpState>>,
     _module_specifier: &ModuleSpecifier,
     _maybe_referrer: Option<ModuleSpecifier>,
     _is_dyn_import: bool,
@@ -146,7 +142,6 @@ pub struct FsModuleLoader;
 impl ModuleLoader for FsModuleLoader {
   fn resolve(
     &self,
-    _op_state: Rc<RefCell<OpState>>,
     specifier: &str,
     referrer: &str,
     _is_main: bool,
@@ -156,7 +151,6 @@ impl ModuleLoader for FsModuleLoader {
 
   fn load(
     &self,
-    _op_state: Rc<RefCell<OpState>>,
     module_specifier: &ModuleSpecifier,
     _maybe_referrer: Option<ModuleSpecifier>,
     _is_dynamic: bool,
@@ -269,18 +263,14 @@ impl RecursiveModuleLoad {
   pub fn resolve_root(&self) -> Result<ModuleSpecifier, AnyError> {
     match self.init {
       LoadInit::Main(ref specifier) => {
-        self
-          .loader
-          .resolve(self.op_state.clone(), specifier, ".", true)
+        self.loader.resolve(specifier, ".", true)
       }
       LoadInit::Side(ref specifier) => {
-        self
-          .loader
-          .resolve(self.op_state.clone(), specifier, ".", false)
+        self.loader.resolve(specifier, ".", false)
+      }
+      LoadInit::DynamicImport(ref specifier, ref referrer) => {
+        self.loader.resolve(specifier, referrer, false)
       }
-      LoadInit::DynamicImport(ref specifier, ref referrer) => self
-        .loader
-        .resolve(self.op_state.clone(), specifier, referrer, false),
     }
   }
 
@@ -288,24 +278,15 @@ impl RecursiveModuleLoad {
     let op_state = self.op_state.clone();
     let (module_specifier, maybe_referrer) = match self.init {
       LoadInit::Main(ref specifier) => {
-        let spec =
-          self
-            .loader
-            .resolve(op_state.clone(), specifier, ".", true)?;
+        let spec = self.loader.resolve(specifier, ".", true)?;
         (spec, None)
       }
       LoadInit::Side(ref specifier) => {
-        let spec =
-          self
-            .loader
-            .resolve(op_state.clone(), specifier, ".", false)?;
+        let spec = self.loader.resolve(specifier, ".", false)?;
         (spec, None)
       }
       LoadInit::DynamicImport(ref specifier, ref referrer) => {
-        let spec =
-          self
-            .loader
-            .resolve(op_state.clone(), specifier, referrer, false)?;
+        let spec = self.loader.resolve(specifier, referrer, false)?;
         (spec, Some(referrer.to_string()))
       }
     };
@@ -389,7 +370,6 @@ impl RecursiveModuleLoad {
             already_registered.push_back((module_id, specifier.clone()));
           } else {
             let fut = self.loader.load(
-              self.op_state.clone(),
               &specifier,
               Some(referrer.clone()),
               self.is_dynamic_import(),
@@ -454,12 +434,7 @@ impl Stream for RecursiveModuleLoad {
           };
           inner
             .loader
-            .load(
-              inner.op_state.clone(),
-              &module_specifier,
-              maybe_referrer,
-              inner.is_dynamic_import(),
-            )
+            .load(&module_specifier, maybe_referrer, inner.is_dynamic_import())
             .boxed_local()
         };
         inner.pending.push(load_fut);
@@ -586,12 +561,8 @@ impl ModuleMap {
       let import_specifier = module_request
         .get_specifier()
         .to_rust_string_lossy(tc_scope);
-      let module_specifier = self.loader.resolve(
-        self.op_state.clone(),
-        &import_specifier,
-        name,
-        false,
-      )?;
+      let module_specifier =
+        self.loader.resolve(&import_specifier, name, false)?;
       import_specifiers.push(module_specifier);
     }
 
@@ -700,12 +671,10 @@ impl ModuleMap {
       .borrow_mut()
       .dynamic_import_map
       .insert(load.id, resolver_handle);
-    let resolve_result = module_map_rc.borrow().loader.resolve(
-      module_map_rc.borrow().op_state.clone(),
-      specifier,
-      referrer,
-      false,
-    );
+    let resolve_result = module_map_rc
+      .borrow()
+      .loader
+      .resolve(specifier, referrer, false);
     let fut = match resolve_result {
       Ok(module_specifier) => {
         if module_map_rc.borrow().is_registered(&module_specifier) {
@@ -737,7 +706,7 @@ impl ModuleMap {
   ) -> Option<v8::Local<'s, v8::Module>> {
     let resolved_specifier = self
       .loader
-      .resolve(self.op_state.clone(), specifier, referrer, false)
+      .resolve(specifier, referrer, false)
       .expect("Module should have been already resolved");
 
     if let Some(id) = self.get_id(resolved_specifier.as_str()) {
@@ -864,7 +833,6 @@ mod tests {
   impl ModuleLoader for MockLoader {
     fn resolve(
       &self,
-      _op_state: Rc<RefCell<OpState>>,
       specifier: &str,
       referrer: &str,
       _is_root: bool,
@@ -891,7 +859,6 @@ mod tests {
 
     fn load(
       &self,
-      _op_state: Rc<RefCell<OpState>>,
       module_specifier: &ModuleSpecifier,
       _maybe_referrer: Option<ModuleSpecifier>,
       _is_dyn_import: bool,
@@ -1010,7 +977,6 @@ mod tests {
     impl ModuleLoader for ModsLoader {
       fn resolve(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         specifier: &str,
         referrer: &str,
         _is_main: bool,
@@ -1024,7 +990,6 @@ mod tests {
 
       fn load(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         _module_specifier: &ModuleSpecifier,
         _maybe_referrer: Option<ModuleSpecifier>,
         _is_dyn_import: bool,
@@ -1130,7 +1095,6 @@ mod tests {
     impl ModuleLoader for DynImportErrLoader {
       fn resolve(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         specifier: &str,
         referrer: &str,
         _is_main: bool,
@@ -1144,7 +1108,6 @@ mod tests {
 
       fn load(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         _module_specifier: &ModuleSpecifier,
         _maybe_referrer: Option<ModuleSpecifier>,
         _is_dyn_import: bool,
@@ -1192,7 +1155,6 @@ mod tests {
   impl ModuleLoader for DynImportOkLoader {
     fn resolve(
       &self,
-      _op_state: Rc<RefCell<OpState>>,
       specifier: &str,
       referrer: &str,
       _is_main: bool,
@@ -1207,7 +1169,6 @@ mod tests {
 
     fn load(
       &self,
-      _op_state: Rc<RefCell<OpState>>,
       specifier: &ModuleSpecifier,
       _maybe_referrer: Option<ModuleSpecifier>,
       _is_dyn_import: bool,
@@ -1330,7 +1291,6 @@ mod tests {
     impl ModuleLoader for DynImportCircularLoader {
       fn resolve(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         specifier: &str,
         referrer: &str,
         _is_main: bool,
@@ -1342,7 +1302,6 @@ mod tests {
 
       fn load(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         specifier: &ModuleSpecifier,
         maybe_referrer: Option<ModuleSpecifier>,
         _is_dyn_import: bool,
@@ -1674,7 +1633,6 @@ mod tests {
     impl ModuleLoader for ModsLoader {
       fn resolve(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         specifier: &str,
         referrer: &str,
         _is_main: bool,
@@ -1685,7 +1643,6 @@ mod tests {
 
       fn load(
         &self,
-        _op_state: Rc<RefCell<OpState>>,
         module_specifier: &ModuleSpecifier,
         _maybe_referrer: Option<ModuleSpecifier>,
         _is_dyn_import: bool,
